"use client";

import { motion, AnimatePresence } from "framer-motion";
import { Application } from "@/types/application";
import ApplicationCard from "./ApplicationCard";

interface ApplicationsListProps {
  applications: Application[];
}

export default function ApplicationsList({ applications }: ApplicationsListProps) {
  return (
    <div className="space-y-4">
      <AnimatePresence>
        {applications.map((application, index) => (
          <motion.div
            key={application.id}
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            exit={{ opacity: 0, y: -20 }}
            transition={{ duration: 0.2, delay: index * 0.05 }}
          >
            <ApplicationCard application={application} />
          </motion.div>
        ))}
      </AnimatePresence>
      
      {applications.length === 0 && (
        <div className="text-center py-12">
          <h3 className="text-lg font-semibold mb-2">No applications found</h3>
          <p className="text-muted-foreground">
            Start by adding a new application or adjust your filters
          </p>
        </div>
      )}
    </div>
  );
}